pub enum CellAlign {
Left,
Center,
Right,
}Expand description
Horizontal text alignment within a table cell.
Registration policy: Specification Required.
Variants
Left
Align text to the left edge of the cell.
Center
Center text horizontally in the cell.
Right
Align text to the right edge of the cell.